# perl module fakeftp.pm

use FileHandle;
use File::Copy;
# This module provides a subset of the Net::FTP behavior, but for
# a local filesystem, but pretending we have a wu-ftp tar-on-the fly
# beast on the far end.  Note that most of them are stubbed out :-).
#
# It provides:
# $ftp->dir();
# $ftp->ok()
# $ftp->close();
# $ftp->binary();
# $ftp->get( $dist, $local, $size );
# $ftp->message();
# $ftp->quit();
# $ftp->put_unique(f)
# $ftp->cwd($dir);

package LocalFTP;
sub new { 
    my $self = {};
    bless $self;
    $self->{pwd} = '/';
    $self->{laststatus} = '0';
    return $self;
}
sub login {
    return 1;
}
sub ok { 
    my $self = shift;
    return 1;
}
sub message { 
    my $self = shift;
    return $self->{laststatus};
}
sub quit {
    return 1;
}
sub binary {
    return 1;
}
sub close {
    return 1;
}
sub dir {
    my $self = shift;
    my $arg = shift;
    my @res = split(/[\r\n]+/, `cd $self->{cwd}; ls $arg`);
    $self->{laststatus} = ($? == 0);
    return @res;
}
sub cwd {
    my $self=shift;
    $self->{cwd} = shift;
}
sub get {
    my $self=shift;
    my ($dist,$loc,$size) = @_;

    $dist = "$self->{cwd}/$dist" unless ($dist =~ m{\A[/]});
    if (! -f $dist && $dist =~ m{(.*)\.tar\Z} && -d $1 ) {
	print "trying tar of $1\n";
        $dist = new FileHandle("cd $1; tar cf - . |");
    }
    File::Copy::copy($dist, $loc);
    $self->{laststatus} = 1;
}

if ($0 =~ m{localftp.pm}) {
   # unit test
   $ftp = new LocalFTP;
   $ftp->login("anonymous","joe\@nowhere.gov");
   $ftp->cwd("/tmp");
   @list = $ftp->dir("-l");
   print join("\n", @list), "\n";
   $ftp->get("junk", "myjunk");
   $ftp->get("foo.tar", "myjunk.tar");
}
1;
